dijit/layout/LayoutContainer Test

## Dijit layout.LayoutContainer tests

Basic layout. Tabindex="0" added to each pane to test for tab order matching source code order. Tab order should be: left, right, top, middle/main, bottom

left
right
top bar
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
bottom bar

Advanced layout. Tabindex="0" added to each pane to test for tab order matching source code order. Tab order should be: left, top, inner left, inner middle, inner right, bottom. This is not an ideal tab order. See below to use nested layout containers to achieve a tab order which matches presentation and source code order.

left
top bar
inner left
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
inner right
bottom bar